Optional data frame to predict on. When omitted, predictions are for the estimation sample and the frame also includes the actual outcome and the residual.
/home/runner/work/expdpy/expdpy/.pixi/envs/docs/lib/python3.12/site-packages/pyfixest/estimation/post_estimation/prediction.py:125: UserWarning: Data types of fixed effects ['country'] do not match the model data. This leads to possible mismatched keys in the fixed effect dictionary -> NaN predictions for new levels.
warnings.warn(