streamlit_app.ExPdPy
streamlit_app.ExPdPy(
df= None ,
cs_id= None ,
ts_id= None ,
df_def= None ,
var_def= None ,
config_list= None ,
* ,
title= _DEFAULT_TITLE,
df_name= None ,
components= None ,
factor_cutoff= 10 ,
export_nb_option= True ,
save_settings_option= True ,
run= True ,
** run_kwargs,
)
Launch (or describe) the interactive Streamlit ExPdPy app.
Parameters
df
Any
A :class:pandas.DataFrame, a mapping of name->DataFrame, a list of DataFrames, or None to start with the bundled-dataset picker / upload dialog.
None
cs_id
Sequence [str ] | str | None
Cross-sectional / time-series identifier column name(s). Overridden by df_def.
None
ts_id
Sequence [str ] | str | None
Cross-sectional / time-series identifier column name(s). Overridden by df_def.
None
df_def
pd .DataFrame | None
Optional variable-definition frame (columns var_name, var_def, type) used to identify the panel dimensions.
None
var_def
pd .DataFrame | None
Optional analysis-sample variable definitions (advanced mode).
None
config_list
dict | None
Optional startup configuration (see :func:expdpy.data.get_config).
None
title
str
App / browser-tab title.
_DEFAULT_TITLE
df_name
str | Sequence [str ] | None
Display name(s) for the provided sample(s).
None
components
Any
Ordered list (or {name: bool} mapping) selecting which components to show.
None
factor_cutoff
int
Numeric columns with at most this many unique values are treated as factors.
10
export_nb_option
bool
Enable the notebook-export and config save/load controls.
True
save_settings_option
bool
Enable the notebook-export and config save/load controls.
True
run
bool
If True (default), start streamlit run in a subprocess and block until it exits; if False, return the command list without launching (used for testing).
True
**run_kwargs
Any
Streamlit server options, e.g. port, host, headless, launch_browser, max_upload_size (mapped to the corresponding --server.* flags).
{}